Møller Auto lietoti auto » Audi A4 2.0 TFSI 110kw aut. 2.0 110kW aut
Description: Møller Auto piedāvā plašu mazlietotu automobiļu izvēli. Mēs arī garantējam, ka automobilis, kuru Jūs pērkat, ir tādā (tehniskajā) stāvoklī, kādu Jūs to sagaidāt.

EST | LAT | LIT | ENG | RUS

- Par mums
- Lietotas automašīnas
- Kontakti

## Meklēt

Spiediet, lai atvērtu meklēšanu
Spiediet, lai aizvērtu meklēšanu
Cena: all
Jauda: all
Gads: all
Nobraukums: all
Tikai piedāvājumus
Aprīkojums
Adaptīvā pneimatiskā balstiekārta ar elektronisku amortizācijas kontroli
Adaptīva piekares regulēšana (DCC)
Kruīzkontrole
Braukšanas joslu maiņas asistents "Side Assist"
Braukšanas joslu uzturēšanas asistents "Lane Assist"
High beam control "Light Assist"
Atpakaļskata kamera
Vieglmetāla diski
LED priekšējie lukturi, automātiska lukturu augstuma regulēšana
DYNAUDIO skaņas sistēma
Navigācijas sistēma
Mobīlā telefona interfeiss
Ādas apdares sēdekļi
Apsildāms priekšējais vējstikls
Elektriski atverms aizmugurējais vāks
R line interjers
R line eksterjers
Piekabes āķis
Garantija
Meklēt pēc automašīnas reģistrācijas nr. - ievadiet numuru:

# Audi A4 2.0 TFSI 110kw aut. 2.0 110kW aut

Atpakaļ
Drukāt

Automašīnas ID: | 10236564 / E866213213
Valsts: | Latvija
Dīleris: | Møller Auto Rīga
Cena: | 33 600.00 € Cena ieskaitot PVN 21%

Līzinga kalkulators

Pirmā reģistrācija: | 07/2020
Nobraukums: | 20 910 km
Reģistrācijas numurs: | MN6786
Virsbūves (VIN) numurs: | WAUZZZF43LA059292
Tehniskā skate: | 07/2022
Dzinēja tilpums: | 2000 cm³
Degviela: | benzīns
Jauda: | 150 ZS (110 kW)
Krāsa: | melna
Virsbūves tips: | sedans
Durvju skaits: | 4/5
Pārnesumkārba: | automātiskā
Garantija: | Ražotāja garantija

Pārnesumkārba

- Automātiskā pārnesumkārba

Drošība un aizsardzība

- Elektromehānisks stūres pastiprinātājs
- ABS bremzes
- ESP stabilitātes kontrole
- ESC stabilitātes kontrole
- EDS/ASR saķeres kontrole
- Elektromehāniskā stāvbremze
- Trešā bremžu uguns
- Isofix bērnu sēdeklīšu stiprinājumi
- Centrālā atslēga ar tālvadības pulti
- Signalizācija ar salona uzraudzību un pretaizdzīšanas aizsardzību
- Lietus sensors

Asistentu sistēmas

- Kruīzkontrole
- Ātruma ierobežotājs
- Audi pre sense - priekšējās daļas uzraudzība
- Parkošanās devēji priekšā un aizmugurē

Riepas un riteņi

- Vieglmetāla diski

Apgaismojums / lukturi

- LED headlights

Multimēdiji

- Skārienjūtīgs ekrāns
- SD karšu ligzda
- USB ligzda
- App Connect
- MMI radio
- MMI navigācija
- Bluetooth interfeiss
- Mobīlā telefona interfeiss

Sēdekļi

- Ādas apdares sēdekļi
- Priekšējo sēdekļu apsilde

Interjers / komforts

- Ādas stūre
- Multifunkciju stūre
- Stūres regulēšana
- Ādas ātrumu pārslēdzējs
- Elektriski logu pacēlāji priekšā un aizmugurē
- Apsildāms aizmugurējais stikls
- Elektriski regulējami spoguļi
- Spoguļu apsilde

Apsilde / kondicionēšana

- Automātiska gaisa kondicionēšanas sistēma "Climatronic"

Cits aprīkojums

- Pagarinātā garantija
- reģistrācijas pak.

### Automašīnu var apskatīt:

Møller Auto Rīga
S. Eizenšteina 10
Rīga LV-1079
E-pasts: ingars.troksa@moller.lv
Tālrunis: +371 28679669
Ingars Trokša
E-pasts: ingars.troksa@moller.lv
Mobīlais tālr.: +37128679669
Atpakaļ
Drukāt